diff --git a/content/projekt/projekt.overlay.js.php b/content/projekt/projekt.overlay.js.php
index fcacf5fac..19fe9e2e1 100644
--- a/content/projekt/projekt.overlay.js.php
+++ b/content/projekt/projekt.overlay.js.php
@@ -153,15 +153,15 @@ function onselectProjekt()
var aufwand_pt=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#aufwand_pt" ));
var anzahl_ma=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#anzahl_ma" ));
var aufwandstyp_kurzbz=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#aufwandstyp_kurzbz" ));
- var buchbar=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#buchbar" ));
+ var zeitaufzeichnung=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#zeitaufzeichnung" ));
- if (!buchbar)
+ if (!zeitaufzeichnung)
{
- buchbar='Nein';
+ zeitaufzeichnung='Nein';
}
else
{
- buchbar='Ja';
+ zeitaufzeichnung='Ja';
}
//Daten den Feldern zuweisen
@@ -179,10 +179,10 @@ function onselectProjekt()
document.getElementById('checkbox-projekt-detail-neu').checked=false;
document.getElementById('textbox-projekt-anzahl_ma').value=anzahl_ma;
document.getElementById('textbox-projekt-aufwand_pt').value=aufwand_pt;
- if(buchbar=='Nein')
- document.getElementById('checkbox-projekt-detail-buchbar').checked=false;
+ if(zeitaufzeichnung=='Nein')
+ document.getElementById('checkbox-projekt-detail-zeitaufzeichnung').checked=false;
else
- document.getElementById('checkbox-projekt-detail-buchbar').checked=true;
+ document.getElementById('checkbox-projekt-detail-zeitaufzeichnung').checked=true;
MenulistSelectItemOnValue('menulist-projekt-detail-aufwandstyp', aufwandstyp_kurzbz);
@@ -217,7 +217,7 @@ function saveProjektDetail()
aufwandstyp_kurzbz = MenulistGetSelectedValue('menulist-projekt-detail-aufwandstyp');
anzahl_ma = document.getElementById('textbox-projekt-anzahl_ma').value;
aufwand_pt = document.getElementById('textbox-projekt-aufwand_pt').value;
- buchbar = document.getElementById('checkbox-projekt-detail-buchbar').checked;
+ zeitaufzeichnung = document.getElementById('checkbox-projekt-detail-zeitaufzeichnung').checked;
var soapBody = new SOAPObject("saveProjekt");
//soapBody.appendChild(new SOAPObject("username")).val('joe');
@@ -237,13 +237,13 @@ function saveProjektDetail()
projekt.appendChild(new SOAPObject("anzahl_ma")).val(anzahl_ma);
projekt.appendChild(new SOAPObject("aufwand_pt")).val(aufwand_pt);
- if(buchbar)
+ if(zeitaufzeichnung)
{
- projekt.appendChild(new SOAPObject("buchbar")).val('true');
+ projekt.appendChild(new SOAPObject("zeitaufzeichnung")).val('true');
}
else
{
- projekt.appendChild(new SOAPObject("buchbar")).val('false');
+ projekt.appendChild(new SOAPObject("zeitaufzeichnung")).val('false');
}
if(neu)
diff --git a/content/projekt/projektdetail.overlay.xul.php b/content/projekt/projektdetail.overlay.xul.php
index 3da872a07..fda08baa5 100644
--- a/content/projekt/projektdetail.overlay.xul.php
+++ b/content/projekt/projektdetail.overlay.xul.php
@@ -166,9 +166,9 @@ echo '';
-
+
-
+
diff --git a/content/projekt/projektphase.overlay.js.php b/content/projekt/projektphase.overlay.js.php
index a9b44fa75..c3114d1e6 100644
--- a/content/projekt/projektphase.overlay.js.php
+++ b/content/projekt/projektphase.overlay.js.php
@@ -161,15 +161,15 @@ function onselectTreeProjektphase()
var budget=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#budget" ));
var personentage=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#personentage" ));
var farbe=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#farbe" ));
- var buchbar=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#buchbar" ));
+ var zeitaufzeichnung=getTargetHelper(dsource,subject,rdfService.GetResource( predicateNS + "#zeitaufzeichnung" ));
- if (!buchbar)
+ if (!zeitaufzeichnung)
{
- buchbar='Nein';
+ zeitaufzeichnung='Nein';
}
else
{
- buchbar='Ja';
+ zeitaufzeichnung='Ja';
}
//alert(typ);
@@ -189,10 +189,10 @@ function onselectTreeProjektphase()
document.getElementById('textbox-projektphase-detail-personentage').value=personentage;
document.getElementById('textbox-projektphase-detail-farbe').value=farbe;
document.getElementById('checkbox-projektphase-detail-neu').checked=false;
- if(buchbar=='Nein')
- document.getElementById('checkbox-projektphase-detail-buchbar').checked=false;
+ if(zeitaufzeichnung=='Nein')
+ document.getElementById('checkbox-projektphase-detail-zeitaufzeichnung').checked=false;
else
- document.getElementById('checkbox-projektphase-detail-buchbar').checked=true;
+ document.getElementById('checkbox-projektphase-detail-zeitaufzeichnung').checked=true;
MenulistSelectItemOnValue('menulist-projektphase-detail-projektphase_fk', projektphase_fk);
MenulistSelectItemOnValue('menulist-projektphase-detail-ressource', ressource_id);
@@ -247,7 +247,7 @@ function saveProjektphaseDetail()
var personentage = document.getElementById('textbox-projektphase-detail-personentage').value;
var farbe = document.getElementById('textbox-projektphase-detail-farbe').value;
var neu = document.getElementById('checkbox-projektphase-detail-neu').checked;
- var buchbar = document.getElementById('checkbox-projektphase-detail-buchbar').checked;
+ var zeitaufzeichnung = document.getElementById('checkbox-projektphase-detail-zeitaufzeichnung').checked;
var soapBody = new SOAPObject("saveProjektphase");
//soapBody.appendChild(new SOAPObject("username")).val('joe');
@@ -266,13 +266,13 @@ function saveProjektphaseDetail()
phase.appendChild(new SOAPObject("budget")).val(budget);
phase.appendChild(new SOAPObject("personentage")).val(personentage);
phase.appendChild(new SOAPObject("farbe")).val(farbe);
- if(buchbar)
+ if(zeitaufzeichnung)
{
- phase.appendChild(new SOAPObject("buchbar")).val('true');
+ phase.appendChild(new SOAPObject("zeitaufzeichnung")).val('true');
}
else
{
- phase.appendChild(new SOAPObject("buchbar")).val('false');
+ phase.appendChild(new SOAPObject("zeitaufzeichnung")).val('false');
}
if(neu)
{
diff --git a/content/projekt/projektphasedetail.overlay.xul.php b/content/projekt/projektphasedetail.overlay.xul.php
index 4d8858af8..eeadf366f 100644
--- a/content/projekt/projektphasedetail.overlay.xul.php
+++ b/content/projekt/projektphasedetail.overlay.xul.php
@@ -145,9 +145,9 @@ echo '';
-
+
-
+
diff --git a/include/projekt.class.php b/include/projekt.class.php
index f2ace5e29..babae4523 100644
--- a/include/projekt.class.php
+++ b/include/projekt.class.php
@@ -47,7 +47,7 @@ class projekt extends basis_db
public $farbe;
public $anzahl_ma; // integer
public $aufwand_pt; // integer
- public $buchbar; //bool
+ public $zeitaufzeichnung; //bool
/**
@@ -86,7 +86,7 @@ class projekt extends basis_db
$this->farbe = $row->farbe;
$this->anzahl_ma = $row->anzahl_ma;
$this->aufwand_pt = $row->aufwand_pt;
- $this->buchbar = $this->db_parse_bool($row->buchbar);
+ $this->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
return true;
}
@@ -141,7 +141,7 @@ class projekt extends basis_db
$obj->aufwandstyp_kurzbz = $row->aufwandstyp_kurzbz;
$obj->anzahl_ma = $row->anzahl_ma;
$obj->aufwand_pt = $row->aufwand_pt;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
@@ -185,7 +185,7 @@ class projekt extends basis_db
$obj->farbe = $row->farbe;
$obj->anzahl_ma = $row->anzahl_ma;
$obj->aufwand_pt = $row->aufwand_pt;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
@@ -229,7 +229,7 @@ class projekt extends basis_db
$obj->aufwandstyp_kurzbz = $row->aufwandstyp_kurzbz;
$obj->anzahl_ma = $row->anzahl_ma;
$obj->aufwand_pt = $row->aufwand_pt;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
@@ -297,7 +297,7 @@ class projekt extends basis_db
{
//Neuen Datensatz einfuegen
- $qry = 'INSERT INTO fue.tbl_projekt (projekt_kurzbz, nummer, titel,beschreibung, beginn, ende, budget, farbe, oe_kurzbz, aufwand_pt, anzahl_ma, aufwandstyp_kurzbz, buchbar) VALUES('.
+ $qry = 'INSERT INTO fue.tbl_projekt (projekt_kurzbz, nummer, titel,beschreibung, beginn, ende, budget, farbe, oe_kurzbz, aufwand_pt, anzahl_ma, aufwandstyp_kurzbz, zeitaufzeichnung) VALUES('.
$this->db_add_param($this->projekt_kurzbz).', '.
$this->db_add_param($this->nummer).', '.
$this->db_add_param($this->titel).', '.
@@ -310,7 +310,7 @@ class projekt extends basis_db
$this->db_add_param($this->aufwand_pt).','.
$this->db_add_param($this->anzahl_ma).','.
$this->db_add_param($this->aufwandstyp_kurzbz).', '.
- $this->db_add_param($this->buchbar,FHC_BOOLEAN).');';
+ $this->db_add_param($this->zeitaufzeichnung,FHC_BOOLEAN).');';
}
else
{
@@ -329,7 +329,7 @@ class projekt extends basis_db
'anzahl_ma='.$this->db_add_param($this->anzahl_ma).', '.
'aufwand_pt='.$this->db_add_param($this->aufwand_pt).', '.
'aufwandstyp_kurzbz='.$this->db_add_param($this->aufwandstyp_kurzbz).', '.
- 'buchbar='.$this->db_add_param($this->buchbar,FHC_BOOLEAN).' '.
+ 'zeitaufzeichnung='.$this->db_add_param($this->zeitaufzeichnung,FHC_BOOLEAN).' '.
'WHERE projekt_kurzbz='.$this->db_add_param($this->projekt_kurzbz).';';
}
@@ -424,7 +424,7 @@ class projekt extends basis_db
$obj->beginn = $row->beginn;
$obj->ende = $row->ende;
$obj->oe_kurzbz = $row->oe_kurzbz;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
@@ -457,7 +457,7 @@ class projekt extends basis_db
$this->farbe = $row->farbe;
$this->anzahl_ma = $row->anzahl_ma;
$this->aufwand_pt = $row->aufwand_pt;
- $this->buchbar = $this->db_parse_bool($row->buchbar);
+ $this->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
return true;
}
diff --git a/include/projektphase.class.php b/include/projektphase.class.php
index 3bb497bef..c5c6f56c3 100644
--- a/include/projektphase.class.php
+++ b/include/projektphase.class.php
@@ -48,7 +48,7 @@ class projektphase extends basis_db
public $insertvon; // bigint
public $updateamum; // timestamp
public $updatevon; // bigint
- public $buchbar; // bool
+ public $zeitaufzeichnung; // bool
/**
@@ -101,7 +101,7 @@ class projektphase extends basis_db
$this->insertvon = $row->insertvon;
$this->updateamum = $row->updateamum;
$this->updatevon = $row->updatevon;
- $this->buchbar = $this->db_parse_bool($row->buchbar);
+ $this->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
return true;
}
else
@@ -160,7 +160,7 @@ class projektphase extends basis_db
$obj->insertvon = $row->insertvon;
$obj->updateamum = $row->updateamum;
$obj->updatevon = $row->updatevon;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
@@ -216,7 +216,7 @@ class projektphase extends basis_db
$obj->insertvon = $row->insertvon;
$obj->updateamum = $row->updateamum;
$obj->updatevon = $row->updatevon;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
//var_dump($this->result);
@@ -263,7 +263,7 @@ class projektphase extends basis_db
$obj->insertvon = $row->insertvon;
$obj->updateamum = $row->updateamum;
$obj->updatevon = $row->updatevon;
- $obj->buchbar = $this->db_parse_bool($row->buchbar);
+ $obj->zeitaufzeichnung = $this->db_parse_bool($row->zeitaufzeichnung);
$this->result[] = $obj;
}
@@ -325,7 +325,7 @@ class projektphase extends basis_db
//Neuen Datensatz einfuegen
$qry='BEGIN; INSERT INTO fue.tbl_projektphase (projekt_kurzbz, projektphase_fk, bezeichnung, typ,
- beschreibung, start, ende, budget, ressource_id, insertvon, insertamum, updatevon, updateamum, farbe, personentage, buchbar) VALUES ('.
+ beschreibung, start, ende, budget, ressource_id, insertvon, insertamum, updatevon, updateamum, farbe, personentage, zeitaufzeichnung) VALUES ('.
$this->db_add_param($this->projekt_kurzbz).', '.
$this->db_add_param($this->projektphase_fk).', '.
$this->db_add_param($this->bezeichnung).', '.
@@ -339,7 +339,7 @@ class projektphase extends basis_db
$this->db_add_param($this->updatevon).', now(), '.
$this->db_add_param($this->farbe).', '.
$this->db_add_param($this->personentage).', '.
- $this->db_add_param($this->buchbar,FHC_BOOLEAN).');';
+ $this->db_add_param($this->zeitaufzeichnung,FHC_BOOLEAN).');';
}
else
{
@@ -359,7 +359,7 @@ class projektphase extends basis_db
'personentage='.$this->db_add_param($this->personentage).', '.
'updateamum= now(), '.
'updatevon='.$this->db_add_param($this->updatevon).', '.
- 'buchbar='.$this->db_add_param($this->buchbar,FHC_BOOLEAN).' '.
+ 'zeitaufzeichnung='.$this->db_add_param($this->zeitaufzeichnung,FHC_BOOLEAN).' '.
'WHERE projektphase_id='.$this->db_add_param($this->projektphase_id, FHC_INTEGER).';';
}
diff --git a/rdf/projekt.rdf.php b/rdf/projekt.rdf.php
index 68415dbf1..38f4c52de 100644
--- a/rdf/projekt.rdf.php
+++ b/rdf/projekt.rdf.php
@@ -72,7 +72,7 @@ for ($i=0;$iresult);$i++)
'.$projekt->anzahl_ma.'
'.$projekt->aufwand_pt.'
'.$projekt->aufwandstyp_kurzbz.'
- '.$projekt->buchbar.'
+ '.$projekt->zeitaufzeichnung.'
'."\n";
$sequenz.=''."\n";
diff --git a/rdf/projektphase.rdf.php b/rdf/projektphase.rdf.php
index a65d41535..dfe3b1f4c 100644
--- a/rdf/projektphase.rdf.php
+++ b/rdf/projektphase.rdf.php
@@ -63,7 +63,7 @@ if($projektphase_id != '')
$oRdf->obj[$i]->setAttribut('farbe',$phase->farbe);
$oRdf->obj[$i]->setAttribut('typ',$phase->typ);
$oRdf->obj[$i]->setAttribut('ressource_id',$phase->ressource_id);
- $oRdf->obj[$i]->setAttribut('buchbar',$phase->buchbar);
+ $oRdf->obj[$i]->setAttribut('zeitaufzeichnung',$phase->zeitaufzeichnung);
if($phase->projektphase_fk!='')
$oRdf->addSequence($phase->projektphase_id, $phase->projektphase_fk);
@@ -95,7 +95,7 @@ if($projektphase_id != '')
$oRdf->obj[$idx]->setAttribut('personentage', '');
$oRdf->obj[$idx]->setAttribut('farbe', '');
$oRdf->obj[$idx]->setAttribut('typ', '');
- $oRdf->obj[$idx]->setAttribut('buchbar','');
+ $oRdf->obj[$idx]->setAttribut('zeitaufzeichnung','');
$oRdf->addSequence('opt');
}
@@ -115,7 +115,7 @@ if($projektphase_id != '')
$oRdf->obj[$idx]->setAttribut('personentage', $phase->personentage);
$oRdf->obj[$idx]->setAttribut('farbe', $phase->farbe);
$oRdf->obj[$idx]->setAttribut('typ', $phase->typ);
- $oRdf->obj[$idx]->setAttribut('buchbar',$phase->buchbar);
+ $oRdf->obj[$idx]->setAttribut('zeitaufzeichnung',$phase->zeitaufzeichnung);
$oRdf->addSequence($phase->projektphase_id);
}
@@ -166,7 +166,7 @@ else
$oRdf->obj[$idx]->setAttribut('beginn','');
$oRdf->obj[$idx]->setAttribut('ende','');
$oRdf->obj[$idx]->setAttribut('typ','organisationseinheit');
- $oRdf->obj[$idx]->setAttribut('buchbar','');
+ $oRdf->obj[$idx]->setAttribut('zeitaufzeichnung','');
$oRdf->addSequence($projekt->oe_kurzbz);
@@ -188,7 +188,7 @@ else
$oRdf->obj[$idx]->setAttribut('beginn',$datum_obj->formatDatum($projekt->beginn,'d.m.Y'));
$oRdf->obj[$idx]->setAttribut('ende',$datum_obj->formatDatum($projekt->ende,'d.m.Y'));
$oRdf->obj[$idx]->setAttribut('typ','projekt');
- $oRdf->obj[$idx]->setAttribut('buchbar',$projekt->buchbar);
+ $oRdf->obj[$idx]->setAttribut('zeitaufzeichnung',$projekt->zeitaufzeichnung);
$oRdf->addSequence($projekt->oe_kurzbz.'/'.$projekt->projekt_kurzbz, $projekt->oe_kurzbz);
@@ -229,7 +229,7 @@ else
$oRdf->obj[$idx]->setAttribut('typ',strtolower($projektphase->typ));
$oRdf->obj[$idx]->setAttribut('ressource_bezeichnung',$projektphase->ressource_bezeichnung);
$oRdf->obj[$idx]->setAttribut('ressource_id',$projektphase->ressource_id);
- $oRdf->obj[$idx]->setAttribut('buchbar',$projektphase->buchbar);
+ $oRdf->obj[$idx]->setAttribut('zeitaufzeichnung',$projektphase->zeitaufzeichnung);
if (!is_null($projektphase->projektphase_fk))
$oRdf->addSequence($projekt->oe_kurzbz.'/'.$projekt->projekt_kurzbz.'/'.$projektphase->projektphase_id, $projekt->oe_kurzbz.'/'.$projekt->projekt_kurzbz.'/'.$projektphase->projektphase_fk);
else
diff --git a/soap/projekt.soap.php b/soap/projekt.soap.php
index bc6f678b9..faeefdc2d 100644
--- a/soap/projekt.soap.php
+++ b/soap/projekt.soap.php
@@ -72,13 +72,13 @@ function saveProjekt($username, $passwort, $projekt)
$projektNew->anzahl_ma = $projekt->anzahl_ma;
$projektNew->aufwand_pt = $projekt->aufwand_pt;
- if($projekt->buchbar=='true')
+ if($projekt->zeitaufzeichnung=='true')
{
- $projektNew->buchbar = true;
+ $projektNew->zeitaufzeichnung = true;
}
else
{
- $projektNew->buchbar = false;
+ $projektNew->zeitaufzeichnung = false;
}
if($projekt->neu=='true')
diff --git a/soap/projekt.wsdl.php b/soap/projekt.wsdl.php
index 832cfc875..a798dc1db 100644
--- a/soap/projekt.wsdl.php
+++ b/soap/projekt.wsdl.php
@@ -30,7 +30,7 @@ xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/">
-
+
diff --git a/soap/projektphase.soap.php b/soap/projektphase.soap.php
index 1d32863bf..640f0c19d 100644
--- a/soap/projektphase.soap.php
+++ b/soap/projektphase.soap.php
@@ -82,13 +82,13 @@ function saveProjektphase($username, $passwort, $phase)
$projektphase->updatevon = $user;
$projektphase->updateamum = date('Y-m-d H:i:s');
- if($phase->buchbar=='true')
+ if($phase->zeitaufzeichnung=='true')
{
- $projektphase->buchbar = true;
+ $projektphase->zeitaufzeichnung = true;
}
else
{
- $projektphase->buchbar = false;
+ $projektphase->zeitaufzeichnung = false;
}
if($phase->neu=='true')
diff --git a/soap/projektphase.wsdl.php b/soap/projektphase.wsdl.php
index 817721ac3..c6aec364a 100644
--- a/soap/projektphase.wsdl.php
+++ b/soap/projektphase.wsdl.php
@@ -35,7 +35,7 @@ xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/">
-
+
diff --git a/system/dbupdate_3.3.php b/system/dbupdate_3.3.php
index 048f8380b..a4174dc15 100644
--- a/system/dbupdate_3.3.php
+++ b/system/dbupdate_3.3.php
@@ -2032,26 +2032,26 @@ if (!$result = @$db->db_query("SELECT projekt_id FROM fue.tbl_projekt LIMIT 1"))
}
-// add column buchbar to fue.tbl_project
-if (!$result = @$db->db_query("SELECT buchbar FROM fue.tbl_projekt LIMIT 1"))
+// add column zeitaufzeichnung to fue.tbl_project
+if (!$result = @$db->db_query("SELECT zeitaufzeichnung FROM fue.tbl_projekt LIMIT 1"))
{
- $qry = "ALTER TABLE fue.tbl_projekt ADD COLUMN buchbar BOOLEAN NOT NULL DEFAULT true;";
+ $qry = "ALTER TABLE fue.tbl_projekt ADD COLUMN zeitaufzeichnung BOOLEAN NOT NULL DEFAULT true;";
if(!$db->db_query($qry))
echo 'fue.tbl_projekt '.$db->db_last_error().'
';
else
- echo '
Spalte buchbar zu fue.tbl_projekt hinzugefügt';
+ echo '
Spalte zeitaufzeichnung zu fue.tbl_projekt hinzugefügt';
}
-// add column buchbar to fue.tbl_projectphase
-if (!$result = @$db->db_query("SELECT buchbar FROM fue.tbl_projektphase LIMIT 1"))
+// add column zeitaufzeichnung to fue.tbl_projectphase
+if (!$result = @$db->db_query("SELECT zeitaufzeichnung FROM fue.tbl_projektphase LIMIT 1"))
{
- $qry = "ALTER TABLE fue.tbl_projektphase ADD COLUMN buchbar BOOLEAN NOT NULL DEFAULT true;";
+ $qry = "ALTER TABLE fue.tbl_projektphase ADD COLUMN zeitaufzeichnung BOOLEAN NOT NULL DEFAULT true;";
if(!$db->db_query($qry))
echo 'fue.tbl_projektphase '.$db->db_last_error().'
';
else
- echo '
Spalte buchbar zu fue.tbl_projektphase hinzugefügt';
+ echo '
Spalte zeitaufzeichnung zu fue.tbl_projektphase hinzugefügt';
}
// Extension Schema